##  Related Resources
[Radar Report](https://help.sap.com/docs/leanix/ea/radar-report?locale=en-US&state=PRODUCTION&version=CLOUD "A Radar report offers a visual representation of fact sheets categorized in rings and sectors. It aids in understanding an organization's tech landscape and evaluate technology standards.")
YesNo
Send
